@@ -28,13 +28,15 @@ from typing import (
 )
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.cloud.apigeeconnect_v1.types import tether
 from google.protobuf import duration_pb2  # type: ignore
 from .transports.base import TetherTransport, DEFAULT_CLIENT_INFO
@@ -166,7 +168,7 @@ class TetherAsyncClient:
         self,
         requests: AsyncIterator[tether.EgressResponse] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Awaitable[AsyncIterable[tether.EgressRequest]]:
